==> django-froala-editor-1.2.1.tar.gz: django-froala-editor-1.2.1/froala_editor/static/froala_editor/js/langs/bs.js <==
/*!
 * froala_editor v1.2.1 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Bosnian.
 */

$.Editable.LANGS['bs'] = {
  translation: {
    "Bold": "Bold",
    "Italic": "Italic",
    "Underline": "Podvu\u010deno",
    "Strikethrough": "Precrtano",
    "Font Size": "Veli\u010dina fonta",
    "Color": "Boja",
    "Background Color": "Boja pozadine",
    "Text Color": "Boja teksta",
    "Format Block": "Formatiranje bloka",
    "Normal": "Normalno",
    "Paragraph": "Paragraf",
    "Code": "Izvorni kod",
    "Quote": "Citat",
    "Heading 1": "Naslov 1",
    "Heading 2": "Naslov 2",
    "Heading 3": "Naslov 3",
    "Heading 4": "Naslov 4",
    "Heading 5": "Naslov 5",
    "Heading 6": "Naslov 6",
    "Block Style": "Blok style",
    "Alignment": "Poravnanje",
    "Align Left": "Poravnaj lijevo",
    "Align Center": "Poravnaj po sredini",
    "Align Right": "Poravnaj desno",
    "Justify": "Obostrano poravnanje",
    "Numbered List": "Numerisana lista",
    "Bulleted List": "Bullet lista",
    "Indent Less": "Uvuci paragraf",
    "Indent More": "Izvuci paragraf",
    "Select All": "Ozna\u010di sve",
    "Insert Link": "Umetni link",
    "Insert Image": "Umetni sliku",
    "Insert Video": "Umetni video",
    "Undo": "Korak nazad",
    "Redo": "Korak naprijed",
    "Show HTML": "Prika\u017ei HTML kod",
    "Float Left": "Prebaci lijevo",
    "Float None": "Bez prebacivanja",
    "Float Right": "Prebaci desno",
    "Replace Image": "Zamijeni ilustraciju",
    "Remove Image": "Ukloni ilustraciju",
    "Title": "Naslov",
    "Insert image": "Umetni ilustraciju",
    "Drop image": "Izbaci ilustraciju",
    "or click": "ili odaberi",
    "or": "ili",
    "Enter URL": "Enter URL",
    "Please wait!": "Molim sa\u010dekaj.",
    "Are you sure? Image will be deleted.": "Da li ste sigurni da \u017eelite da obri\u0161ete ovu ilustraciju?",
    "UNLINK": "Ukloni link",
    "Open in new tab": "Otvori u novom prozoru",
    "Type something": "Ukucajte ne\u0161tp",
    "Cancel": "Otka\u017ei",
    "OK": "U redu",
    "Manage images": "Upravljanje ilustracijama",
    "Delete": "Obri\u0161i",
    "Font Family": "Odaberi font",
    "Insert Horizontal Line": "Umetni vodoravna liniju",
    "Table": "Tabela",
    "Insert table": "Umetni tabelu",
    "Cell": "\u0106elija",
    "Row": "Red",
    "Column": "Kolona",
    "Delete table": "Obri\u0161i tabelu",
    "Insert cell before": "Umetni \u0107elije prije",
    "Insert cell after": "Umetni \u0107elije posle",
    "Delete cell": "Obri\u0161i \u0107elije",
    "Merge cells": "Spoji \u0107elija",
    "Horizontal split": "Horizontalno razdvajanje polja",
    "Vertical split": "Vertikalno razdvajanje polja",
    "Insert row above": "Umetni red iznad",
    "Insert row below": "Umetni red ispod",
    "Delete row": "Obri\u0161i red",
    "Insert column before": "Umetni kolonu prije",
    "Insert column after": "Umetni kolonu poslije",
    "Delete column": "Obri\u0161i kolonu"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.3.tar.gz: django-froala-editor-1.2.3/froala_editor/static/froala_editor/js/langs/bs.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Bosnian.
 */

$.Editable.LANGS['bs'] = {
  translation: {
    "Bold": "Bold",
    "Italic": "Italic",
    "Underline": "Podvu\u010deno",
    "Strikethrough": "Precrtano",
    "Font Size": "Veli\u010dina fonta",
    "Color": "Boja",
    "Background": "Pozadine",
    "Text": "Teksta",
    "Format Block": "Formatiranje bloka",
    "Normal": "Normalno",
    "Paragraph": "Paragraf",
    "Code": "Izvorni kod",
    "Quote": "Citat",
    "Heading 1": "Naslov 1",
    "Heading 2": "Naslov 2",
    "Heading 3": "Naslov 3",
    "Heading 4": "Naslov 4",
    "Heading 5": "Naslov 5",
    "Heading 6": "Naslov 6",
    "Block Style": "Blok style",
    "Alignment": "Poravnanje",
    "Align Left": "Poravnaj lijevo",
    "Align Center": "Poravnaj po sredini",
    "Align Right": "Poravnaj desno",
    "Justify": "Obostrano poravnanje",
    "Numbered List": "Numerisana lista",
    "Bulleted List": "Bullet lista",
    "Indent Less": "Uvuci paragraf",
    "Indent More": "Izvuci paragraf",
    "Select All": "Ozna\u010di sve",
    "Insert Link": "Umetni link",
    "Insert Image": "Umetni sliku",
    "Insert Video": "Umetni video",
    "Undo": "Korak nazad",
    "Redo": "Korak naprijed",
    "Show HTML": "Prika\u017ei HTML kod",
    "Float Left": "Prebaci lijevo",
    "Float None": "Bez prebacivanja",
    "Float Right": "Prebaci desno",
    "Replace Image": "Zamijeni ilustraciju",
    "Remove Image": "Ukloni ilustraciju",
    "Title": "Naslov",
    "Drop image": "Izbaci ilustraciju",
    "or click": "ili odaberi",
    "or": "ili",
    "Enter URL": "Enter URL",
    "Please wait!": "Molim sa\u010dekaj.",
    "Are you sure? Image will be deleted.": "Da li ste sigurni da \u017eelite da obri\u0161ete ovu ilustraciju?",
    "UNLINK": "Ukloni link",
    "Open in new tab": "Otvori u novom prozoru",
    "Type something": "Ukucajte ne\u0161tp",
    "Cancel": "Otka\u017ei",
    "OK": "U redu",
    "Manage images": "Upravljanje ilustracijama",
    "Delete": "Obri\u0161i",
    "Font Family": "Odaberi font",
    "Insert Horizontal Line": "Umetni vodoravna liniju",
    "Table": "Tabela",
    "Insert table": "Umetni tabelu",
    "Cell": "\u0106elija",
    "Row": "Red",
    "Column": "Kolona",
    "Delete table": "Obri\u0161i tabelu",
    "Insert cell before": "Umetni \u0107elije prije",
    "Insert cell after": "Umetni \u0107elije posle",
    "Delete cell": "Obri\u0161i \u0107elije",
    "Merge cells": "Spoji \u0107elija",
    "Horizontal split": "Horizontalno razdvajanje polja",
    "Vertical split": "Vertikalno razdvajanje polja",
    "Insert row above": "Umetni red iznad",
    "Insert row below": "Umetni red ispod",
    "Delete row": "Obri\u0161i red",
    "Insert column before": "Umetni kolonu prije",
    "Insert column after": "Umetni kolonu poslije",
    "Delete column": "Obri\u0161i kolonu"
  },
  direction: "ltr"
};
